==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/KeyAction.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include "ActionCommand.h"
#include "ActionFO.h"
#include "KeyAction.h"
#include "KeyEntry.h"
#include "Scene/SceneMediator.h"

KeyAction::KeyAction(ActionFO* target, ActionCommand* pressed, ActionCommand* released)
{
    if ( released == NULL ) {
        throw ("KeyAction::KeyAction(ActionFO*, ActionCommand*, ActionCommand*): NULL pointer is set.\n");
    }
    setTarget(target);
    setCommandPressed(pressed);
    setCommandReleased(released);
}

KeyAction::KeyAction(ActionFO* target, KeyEntry* keyEntry)
{
    if ( keyEntry->commandReleased == NULL ) {
        throw ("KeyAction::KeyAction(ActionFO*, KeyEntry*): NULL pointer is set.\n");
    }
    setTarget(target);
    setCommandPressed(keyEntry->commandPressed);
    setCommandReleased(keyEntry->commandReleased);
    setKeyName(keyEntry->keyName);
    setKeySym(keyEntry->keySym);
}

void KeyAction::setTarget(ActionFO* target)
{
    this->target = target;
}

void KeyAction::setCommandPressed(ActionCommand* command)
{
    this->commandPressed = command;
}

void KeyAction::setCommandReleased(ActionCommand* command)
{
    this->commandReleased = command;
    if ( command == NULL ) {
        throw ("KeyAction::setCommandReleased: NULL pointer is set.\n");
    }
}

bool KeyAction::keyPressed(SceneMediator* mediator)
{
    commandPressed->action(mediator, target);
    return true;
}

bool KeyAction::keyReleased(SceneMediator* mediator)
{
    commandReleased->action(mediator, target);
    return true;
}

void KeyAction::destroy()
{
    commandPressed->destroy();
    commandReleased->destroy();
    delete this;
}

void KeyAction::destroy(SceneMediator* mediator)
{
    mediator->removeKeyListener(getKeyName());
    destroy();
}

void KeyAction::entry(SceneMediator* mediator)
{
    mediator->addKeyListener(getKeyName(), this);
    mediator->addKeyEvent(getKeyName(), getKeySym());
}

KeyAction* KeyAction::clone()
{
    KeyAction* keyAction = new KeyAction(target, commandPressed->clone(), commandReleased->clone());
    keyAction->setKeyName(getKeyName());
    keyAction->setKeySym(getKeySym());
    return keyAction;
}

==> daikon-1.1.tar.gz: daikon-1.1/src/KeyAction.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include "ActionCommand.h"
#include "ActionFO.h"
#include "KeyAction.h"
#include "KeyEntry.h"
#include "Scene/SceneMediator.h"
#include "GC.h"

KeyAction* KeyAction::create(ActionFO* target, ActionCommand* pressed, ActionCommand* released)
{
    if ( released == NULL ) {
        throw ("KeyAction::KeyAction(ActionFO*, ActionCommand*, ActionCommand*): NULL pointer is set.\n");
    }
    KeyAction* ka = GC<KeyAction>::getInstance();
    ka->setTarget(target);
    ka->setCommandPressed(pressed);
    ka->setCommandReleased(released);
    return ka;
}

KeyAction* KeyAction::create(ActionFO* target, KeyEntry* keyEntry)
{
    if ( keyEntry->commandReleased == NULL ) {
        throw ("KeyAction::KeyAction(ActionFO*, KeyEntry*): NULL pointer is set.\n");
    }
    KeyAction* ka = GC<KeyAction>::getInstance();
    ka->setTarget(target);
    ka->setCommandPressed(keyEntry->commandPressed);
    ka->setCommandReleased(keyEntry->commandReleased);
    ka->setKeyName(keyEntry->keyName);
    ka->setKeySym(keyEntry->keySym);
    return ka;
}

void KeyAction::setTarget(ActionFO* target)
{
    this->target = target;
}

void KeyAction::setCommandPressed(ActionCommand* command)
{
    this->commandPressed = command;
}

void KeyAction::setCommandReleased(ActionCommand* command)
{
    this->commandReleased = command;
    if ( command == NULL ) {
        throw ("KeyAction::setCommandReleased: NULL pointer is set.\n");
    }
}

bool KeyAction::keyPressed(SceneMediator* mediator)
{
    commandPressed->action(mediator, target);
    return true;
}

bool KeyAction::keyReleased(SceneMediator* mediator)
{
    commandReleased->action(mediator, target);
    return true;
}

void KeyAction::destroy()
{
    commandPressed->destroy();
    commandReleased->destroy();
    GC<KeyAction>::destroy(this);
}

void KeyAction::destroy(SceneMediator* mediator)
{
    mediator->removeKeyListener(getKeyName());
    destroy();
}

void KeyAction::entry(SceneMediator* mediator)
{
    mediator->addKeyListener(getKeyName(), this);
    mediator->addKeyEvent(getKeyName(), getKeySym());
}

KeyAction* KeyAction::clone()
{
    KeyAction* keyAction = KeyAction::create(target, commandPressed->clone(), commandReleased->clone());
    keyAction->setKeyName(getKeyName());
    keyAction->setKeySym(getKeySym());
    return keyAction;
}
